# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/database_error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/database_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0device/heat_pump/command/v1/database_error.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"\\\n\rDatabaseError\x12:\n\nerror_type\x18\x01 \x01(\x0e\x32&.device.heat_pump.command.v1.ErrorType\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t*\xfc\x01\n\tErrorType\x12\x1a\n\x16\x45RROR_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45RROR_TYPE_MISSING_KEY\x10\x01\x12#\n\x1f\x45RROR_TYPE_FAILED_TO_STORE_DATA\x10\x02\x12\"\n\x1e\x45RROR_TYPE_FAILED_TO_LOAD_DATA\x10\x03\x12\"\n\x1e\x45RROR_TYPE_FAILED_TO_SERIALIZE\x10\x04\x12$\n ERROR_TYPE_FAILED_TO_DESERIALIZE\x10\x05\x12$\n ERROR_TYPE_FAILED_TO_DELETE_DATA\x10\x06\x42\xce\x01\n-com.aira.contract.device.heat_pump.command.v1B\x12\x44\x61tabaseErrorProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.database_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\022DatabaseErrorProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_ERRORTYPE']._serialized_start=176
  _globals['_ERRORTYPE']._serialized_end=428
  _globals['_DATABASEERROR']._serialized_start=81
  _globals['_DATABASEERROR']._serialized_end=173
# @@protoc_insertion_point(module_scope)