# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/util/v1/water_tank_size.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/util/v1/water_tank_size.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.device/heat_pump/util/v1/water_tank_size.proto\x12\x18\x64\x65vice.heat_pump.util.v1*\xf0\x01\n\rWaterTankSize\x12\x1f\n\x1bWATER_TANK_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aWATER_TANK_SIZE_100_LITERS\x10\x01\x12\x1e\n\x1aWATER_TANK_SIZE_150_LITERS\x10\x03\x12\x1e\n\x1aWATER_TANK_SIZE_200_LITERS\x10\x04\x12\x1e\n\x1aWATER_TANK_SIZE_250_LITERS\x10\x02\x12\x1e\n\x1aWATER_TANK_SIZE_300_LITERS\x10\x06\x12\x18\n\x14WATER_TANK_SIZE_NONE\x10\x07\"\x04\x08\x05\x10\x05\x42\xbf\x01\n*com.aira.contract.device.heat_pump.util.v1B\x12WaterTankSizeProtoP\x01\xa2\x02\x03\x44HU\xaa\x02\x17\x44\x65vice.HeatPump.Util.V1\xca\x02\x17\x44\x65vice\\HeatPump\\Util\\V1\xe2\x02#Device\\HeatPump\\Util\\V1\\GPBMetadata\xea\x02\x1a\x44\x65vice::HeatPump::Util::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.util.v1.water_tank_size_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.aira.contract.device.heat_pump.util.v1B\022WaterTankSizeProtoP\001\242\002\003DHU\252\002\027Device.HeatPump.Util.V1\312\002\027Device\\HeatPump\\Util\\V1\342\002#Device\\HeatPump\\Util\\V1\\GPBMetadata\352\002\032Device::HeatPump::Util::V1'
  _globals['_WATERTANKSIZE']._serialized_start=77
  _globals['_WATERTANKSIZE']._serialized_end=317
# @@protoc_insertion_point(module_scope)