# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/configure_heat_pump.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/configure_heat_pump.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...config.v1 import config_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5device/heat_pump/command/v1/configure_heat_pump.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\'device/heat_pump/config/v1/config.proto\"G\n\x11\x43onfigureHeatPump\x12\x32\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\".device.heat_pump.config.v1.Config\"`\n\x0e\x43\x63vConfigError\x12=\n\x04\x63ode\x18\x01 \x01(\x0e\x32/.device.heat_pump.command.v1.CcvConfigErrorCode\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t\"N\n\x0f\x43\x63vConfigErrors\x12;\n\x06\x65rrors\x18\x01 \x03(\x0b\x32+.device.heat_pump.command.v1.CcvConfigError\"h\n\x0b\x43onfigError\x12I\n\x11\x63\x63v_config_errors\x18\x01 \x01(\x0b\x32,.device.heat_pump.command.v1.CcvConfigErrorsH\x00\x42\x0e\n\x0c\x63onfig_error*\x8d\x06\n\x12\x43\x63vConfigErrorCode\x12%\n!CCV_CONFIG_ERROR_CODE_UNSPECIFIED\x10\x00\x12(\n$CCV_CONFIG_ERROR_CODE_SENSOR_SOURCES\x10\x01\x12-\n)CCV_CONFIG_ERROR_CODE_COMPRESSOR_SETTINGS\x10\x02\x12&\n\"CCV_CONFIG_ERROR_CODE_HEATING_MODE\x10\x03\x12(\n$CCV_CONFIG_ERROR_CODE_HEATING_SYSTEM\x10\x04\x12$\n CCV_CONFIG_ERROR_CODE_DHW_SYSTEM\x10\x05\x12#\n\x1f\x43\x43V_CONFIG_ERROR_CODE_AWAY_MODE\x10\x06\x12)\n%CCV_CONFIG_ERROR_CODE_HEATING_COOLING\x10\x07\x12+\n\'CCV_CONFIG_ERROR_CODE_OUTDOOR_UNIT_SIZE\x10\x08\x12\'\n#CCV_CONFIG_ERROR_CODE_FACTORY_RESET\x10\t\x12$\n CCV_CONFIG_ERROR_CODE_PUMP_SPEED\x10\n\x12*\n&CCV_CONFIG_ERROR_CODE_ALARM_THRESHOLDS\x10\x0b\x12/\n+CCV_CONFIG_ERROR_CODE_REBOOT_WAIT_TIMED_OUT\x10\x0c\x12+\n\'CCV_CONFIG_ERROR_CODE_ELECTRICITY_METER\x10\r\x12-\n)CCV_CONFIG_ERROR_CODE_INLINE_HEATER_STEPS\x10\x0e\x12$\n CCV_CONFIG_ERROR_CODE_NIGHT_MODE\x10\x0f\x12%\n!CCV_CONFIG_ERROR_CODE_FLOW_METERS\x10\x10\x12-\n)CCV_CONFIG_ERROR_CODE_ENERGY_BALANCY_KICK\x10\x11\x42\xd2\x01\n-com.aira.contract.device.heat_pump.command.v1B\x16\x43onfigureHeatPumpProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.configure_heat_pump_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\026ConfigureHeatPumpProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_CCVCONFIGERRORCODE']._serialized_start=485
  _globals['_CCVCONFIGERRORCODE']._serialized_end=1266
  _globals['_CONFIGUREHEATPUMP']._serialized_start=127
  _globals['_CONFIGUREHEATPUMP']._serialized_end=198
  _globals['_CCVCONFIGERROR']._serialized_start=200
  _globals['_CCVCONFIGERROR']._serialized_end=296
  _globals['_CCVCONFIGERRORS']._serialized_start=298
  _globals['_CCVCONFIGERRORS']._serialized_end=376
  _globals['_CONFIGERROR']._serialized_start=378
  _globals['_CONFIGERROR']._serialized_end=482
# @@protoc_insertion_point(module_scope)