# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_invitation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user_account/v2/user_invitation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%user_account/v2/user_invitation.proto\x12\x0fuser_account.v2\x1a\x12util/v2/uuid.proto\"\x82\x01\n\x1cInviteUserToHouseholdRequest\x12&\n\x0finviter_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x15\n\rinvitee_email\x18\x02 \x01(\t\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\"\x1f\n\x1dInviteUserToHouseholdResponse\"0\n\x17\x41\x63\x63\x65ptInvitationRequest\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\"\x1a\n\x18\x41\x63\x63\x65ptInvitationResponse\"t\n\"GetInvitationsByHouseholdIdRequest\x12)\n\x12household_owner_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"Q\n#GetInvitationsByHouseholdIdResponse\x12*\n\x08invitees\x18\x01 \x03(\x0b\x32\x18.user_account.v2.Invitee\" \n\x07Invitee\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\"}\n\x17\x44\x65leteInvitationRequest\x12&\n\x0finviter_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x15\n\rinvitee_email\x18\x02 \x01(\t\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\"\x1a\n\x18\x44\x65leteInvitationResponse2\xec\x03\n\x15UserInvitationService\x12v\n\x15InviteUserToHousehold\x12-.user_account.v2.InviteUserToHouseholdRequest\x1a..user_account.v2.InviteUserToHouseholdResponse\x12g\n\x10\x41\x63\x63\x65ptInvitation\x12(.user_account.v2.AcceptInvitationRequest\x1a).user_account.v2.AcceptInvitationResponse\x12\x88\x01\n\x1bGetInvitationsByHouseholdId\x12\x33.user_account.v2.GetInvitationsByHouseholdIdRequest\x1a\x34.user_account.v2.GetInvitationsByHouseholdIdResponse\x12g\n\x10\x44\x65leteInvitation\x12(.user_account.v2.DeleteInvitationRequest\x1a).user_account.v2.DeleteInvitationResponseB\x91\x01\n!com.aira.contract.user_account.v2B\x13UserInvitationProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_invitation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.user_account.v2B\023UserInvitationProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_INVITEUSERTOHOUSEHOLDREQUEST']._serialized_start=79
  _globals['_INVITEUSERTOHOUSEHOLDREQUEST']._serialized_end=209
  _globals['_INVITEUSERTOHOUSEHOLDRESPONSE']._serialized_start=211
  _globals['_INVITEUSERTOHOUSEHOLDRESPONSE']._serialized_end=242
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_start=244
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_end=292
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_start=294
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_end=320
  _globals['_GETINVITATIONSBYHOUSEHOLDIDREQUEST']._serialized_start=322
  _globals['_GETINVITATIONSBYHOUSEHOLDIDREQUEST']._serialized_end=438
  _globals['_GETINVITATIONSBYHOUSEHOLDIDRESPONSE']._serialized_start=440
  _globals['_GETINVITATIONSBYHOUSEHOLDIDRESPONSE']._serialized_end=521
  _globals['_INVITEE']._serialized_start=523
  _globals['_INVITEE']._serialized_end=555
  _globals['_DELETEINVITATIONREQUEST']._serialized_start=557
  _globals['_DELETEINVITATIONREQUEST']._serialized_end=682
  _globals['_DELETEINVITATIONRESPONSE']._serialized_start=684
  _globals['_DELETEINVITATIONRESPONSE']._serialized_end=710
  _globals['_USERINVITATIONSERVICE']._serialized_start=713
  _globals['_USERINVITATIONSERVICE']._serialized_end=1205
# @@protoc_insertion_point(module_scope)