# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...command.v1 import set_cool_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__cool__curve__deltas__pb2
from ...command.v1 import set_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__heat__curve__deltas__pb2
from ...command.v1 import set_zone_setpoints_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__zone__setpoints__pb2
from ...config.v1.ccv.v1 import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2
from . import error_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_error__pb2
from . import features_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_features__pb2
from . import force_heating_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_force__heating__pb2
from . import heat_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_heat__pb2
from . import led_pattern_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_led__pattern__pb2
from . import power_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_power__pb2
from . import versions_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_versions__pb2
from ....wall_thermostat.broadcast.v1 import wall_thermostat_update_pb2 as device_dot_wall__thermostat_dot_broadcast_dot_v1_dot_wall__thermostat__update__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....schedule.v1 import action_pb2 as schedule_dot_v1_dot_action__pb2
from .....schedule.v1 import schedule_pb2 as schedule_dot_v1_dot_schedule__pb2
from .....util.v1 import time_zone_pb2 as util_dot_v1_dot_time__zone__pb2
from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/state.proto\x12\x19\x64\x65vice.heat_pump.state.v1\x1a\x37\x64\x65vice/heat_pump/command/v1/set_cool_curve_deltas.proto\x1a\x37\x64\x65vice/heat_pump/command/v1/set_heat_curve_deltas.proto\x1a\x34\x64\x65vice/heat_pump/command/v1/set_zone_setpoints.proto\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\x1a%device/heat_pump/state/v1/error.proto\x1a(device/heat_pump/state/v1/features.proto\x1a-device/heat_pump/state/v1/force_heating.proto\x1a$device/heat_pump/state/v1/heat.proto\x1a+device/heat_pump/state/v1/led_pattern.proto\x1a%device/heat_pump/state/v1/power.proto\x1a(device/heat_pump/state/v1/versions.proto\x1a@device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18schedule/v1/action.proto\x1a\x1aschedule/v1/schedule.proto\x1a\x17util/v1/time_zone.proto\x1a\x12util/v1/uuid.proto\"\xbd\x14\n\x05State\x12#\n\x0cheat_pump_id\x18\x07 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\ttime_zone\x18) \x01(\x0b\x32\x11.util.v1.TimeZone\x12\x39\n\x15\x61ws_iot_received_time\x18\' \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x1d\x64\x65precated_target_indoor_heat\x18\x02 \x01(\x0b\x32\x1f.device.heat_pump.state.v1.HeatB\x02\x18\x01\x12M\n\x16zone_setpoints_heating\x18\x18 \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12$\n\x1ctarget_hot_water_temperature\x18\x03 \x01(\x02\x12%\n\x1d\x63urrent_hot_water_temperature\x18\x04 \x01(\x02\x12#\n\x1b\x63urrent_outdoor_temperature\x18\x08 \x01(\x02\x12\x31\n%deprecated_current_indoor_temperature\x18\t \x01(\x02\x42\x02\x18\x01\x12H\n\x11zone_temperatures\x18\x19 \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12%\n\x19\x64\x65precated_linux_build_id\x18\n \x01(\tB\x02\x18\x01\x12:\n\x0bled_pattern\x18\x0c \x01(\x0e\x32%.device.heat_pump.state.v1.LedPattern\x12\x46\n\x11signature_element\x18$ \x01(\x0b\x32+.device.heat_pump.state.v1.SignatureElement\x12\x30\n\x06\x65rrors\x18\r \x03(\x0b\x32 .device.heat_pump.state.v1.Error\x12?\n\x18\x61way_mode_remaining_time\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01\x12,\n\x08\x63\x63v_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x08versions\x18\x10 \x01(\x0b\x32+.device.heat_pump.state.v1.SoftwareVersions\x12 \n\x13manual_mode_enabled\x18\x11 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12night_mode_enabled\x18# \x01(\x08H\x01\x88\x01\x01\x12\x44\n\x10operating_status\x18\x12 \x01(\x0e\x32*.device.heat_pump.state.v1.OperatingStatus\x12:\n\x0bheat_curves\x18\x13 \x01(\x0b\x32%.device.heat_pump.state.v1.HeatCurves\x12G\n\x11heat_curve_deltas\x18\x14 \x01(\x0b\x32,.device.heat_pump.command.v1.HeatCurveDeltas\x12@\n\x0fhot_water_boost\x18\x16 \x01(\x0b\x32#.device.heat_pump.state.v1.DhwBoostB\x02\x18\x01\x12@\n\x0e\x65rror_metadata\x18\x17 \x01(\x0b\x32(.device.heat_pump.state.v1.ErrorMetadata\x12M\n\x16zone_setpoints_cooling\x18\x1b \x01(\x0b\x32-.device.heat_pump.command.v1.ZoneTemperatures\x12:\n\x0b\x63ool_curves\x18\x1c \x01(\x0b\x32%.device.heat_pump.state.v1.CoolCurves\x12G\n\x11\x63ool_curve_deltas\x18\x1d \x01(\x0b\x32,.device.heat_pump.command.v1.CoolCurveDeltas\x12P\n\x1a\x64\x65precated_pump_mode_state\x18\x1e \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeStateB\x02\x18\x01\x12\x16\n\tnum_zones\x18\x1f \x01(\rH\x02\x88\x01\x01\x12:\n\x0bthermostats\x18  \x03(\x0b\x32%.device.heat_pump.state.v1.Thermostat\x12M\n\x17\x63urrent_pump_mode_state\x18! \x01(\x0b\x32,.device.heat_pump.state.v1.ZonePumpModeState\x12I\n\x17\x61llowed_pump_mode_state\x18\" \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12G\n\x15\x63onfigured_pump_modes\x18& \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12\x36\n\thot_water\x18% \x01(\x0b\x32#.device.heat_pump.state.v1.HotWater\x12\x35\n\x08\x66\x65\x61tures\x18( \x01(\x0b\x32#.device.heat_pump.state.v1.Features\x12\x1d\n\x11\x61way_mode_enabled\x18* \x01(\x08\x42\x02\x18\x01\x12\x37\n\tscheduler\x18+ \x01(\x0b\x32$.device.heat_pump.state.v1.Scheduler\x12\x45\n\x11pump_active_state\x18, \x01(\x0e\x32*.device.heat_pump.state.v1.PumpActiveState\x12!\n\x14inline_heater_active\x18- \x01(\x08H\x03\x88\x01\x01\x12\x39\n\x05power\x18. \x01(\x0b\x32%.device.heat_pump.state.v1.PowerStateH\x04\x88\x01\x01\x12>\n\rforce_heating\x18/ \x01(\x0b\x32\'.device.heat_pump.state.v1.ForceHeating\x12\x44\n\x10power_preference\x18\x30 \x01(\x0e\x32*.device.heat_pump.state.v1.PowerPreferenceB\x16\n\x14_manual_mode_enabledB\x15\n\x13_night_mode_enabledB\x0c\n\n_num_zonesB\x17\n\x15_inline_heater_activeB\x08\n\x06_powerJ\x04\x08\x0b\x10\x0cJ\x04\x08\x06\x10\x07J\x04\x08\x05\x10\x06J\x04\x08\x15\x10\x16J\x04\x08\x1a\x10\x1bR\x10wall_thermostats\"\xa6\x01\n\nHeatCurves\x12K\n\x06zone_1\x18\x01 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\x12K\n\x06zone_2\x18\x02 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\"\xa6\x01\n\nCoolCurves\x12K\n\x06zone_1\x18\x01 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\x12K\n\x06zone_2\x18\x02 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\"l\n\x08\x44hwBoost\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x18\x01\"\x98\x01\n\rErrorMetadata\x12\x1e\n\x16hp_has_stopping_alarms\x18\x01 \x01(\x08\x12%\n\x1dhp_has_acknowledgeable_alarms\x18\x02 \x01(\x08\x12\x19\n\x11hp_has_some_alarm\x18\x03 \x01(\x08\x12%\n\x1d\x63ompressor_has_stopping_alarm\x18\x04 \x01(\x08\"\x91\x02\n\nThermostat\x12\x16\n\x0e\x61rticle_number\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12N\n\x0blast_update\x18\x03 \x01(\x0b\x32\x39.device.wall_thermostat.broadcast.v1.WallThermostatUpdate\x12\x39\n\x15last_update_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x04zone\x18\x05 \x01(\x0e\x32\x1f.device.heat_pump.state.v1.Zone\x12\x11\n\x04rssi\x18\x06 \x01(\x05H\x00\x88\x01\x01\x42\x07\n\x05_rssi\"\x87\x01\n\x11ZonePumpModeState\x12\x38\n\x06zone_1\x18\x01 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\x12\x38\n\x06zone_2\x18\x02 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeState\"4\n\x10SignatureElement\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"<\n\x08HotWater\x12\x1c\n\x0fheating_enabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x12\n\x10_heating_enabled\"f\n\tScheduler\x12(\n\tschedules\x18\x01 \x03(\x0b\x32\x15.schedule.v1.Schedule\x12/\n\x0e\x61\x63tive_actions\x18\x02 \x03(\x0b\x32\x13.schedule.v1.ActionB\x02\x18\x01*\x90\x01\n\x0fOperatingStatus\x12 \n\x1cOPERATING_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18OPERATING_STATUS_STANDBY\x10\x01\x12\x19\n\x15OPERATING_STATUS_AUTO\x10\x02\x12\"\n\x1eOPERATING_STATUS_USER_SPECIFIC\x10\x03*4\n\x04Zone\x12\x14\n\x10ZONE_UNSPECIFIED\x10\x00\x12\n\n\x06ZONE_1\x10\x01\x12\n\n\x06ZONE_2\x10\x02*\xa9\x01\n\rPumpModeState\x12\x1f\n\x1bPUMP_MODE_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14PUMP_MODE_STATE_IDLE\x10\x01\x12\x1b\n\x17PUMP_MODE_STATE_HEATING\x10\x02\x12\x1b\n\x17PUMP_MODE_STATE_COOLING\x10\x03\x12#\n\x1fPUMP_MODE_STATE_HEATING_COOLING\x10\x04*\xf2\x01\n\x0fPumpActiveState\x12!\n\x1dPUMP_ACTIVE_STATE_UNSPECIFIED\x10\x00\x12\x1a\n\x16PUMP_ACTIVE_STATE_IDLE\x10\x01\x12\x1d\n\x19PUMP_ACTIVE_STATE_HEATING\x10\x02\x12\x1d\n\x19PUMP_ACTIVE_STATE_COOLING\x10\x03\x12\x19\n\x15PUMP_ACTIVE_STATE_DHW\x10\x04\x12%\n!PUMP_ACTIVE_STATE_ANTI_LEGIONELLA\x10\x05\x12 \n\x1cPUMP_ACTIVE_STATE_DEFROSTING\x10\x06*x\n\x0fPowerPreference\x12 \n\x1cPOWER_PREFERENCE_UNSPECIFIED\x10\x00\x12\x1c\n\x18POWER_PREFERENCE_SAVINGS\x10\x01\x12%\n!POWER_PREFERENCE_SELF_CONSUMPTION\x10\x02\x42\xbc\x01\n+com.aira.contract.device.heat_pump.state.v1B\nStateProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\nStateProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_STATE'].fields_by_name['deprecated_target_indoor_heat']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_target_indoor_heat']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_current_indoor_temperature']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_current_indoor_temperature']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_linux_build_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_linux_build_id']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['away_mode_remaining_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['away_mode_remaining_time']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['hot_water_boost']._loaded_options = None
  _globals['_STATE'].fields_by_name['hot_water_boost']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['deprecated_pump_mode_state']._loaded_options = None
  _globals['_STATE'].fields_by_name['deprecated_pump_mode_state']._serialized_options = b'\030\001'
  _globals['_STATE'].fields_by_name['away_mode_enabled']._loaded_options = None
  _globals['_STATE'].fields_by_name['away_mode_enabled']._serialized_options = b'\030\001'
  _globals['_DHWBOOST']._loaded_options = None
  _globals['_DHWBOOST']._serialized_options = b'\030\001'
  _globals['_SCHEDULER'].fields_by_name['active_actions']._loaded_options = None
  _globals['_SCHEDULER'].fields_by_name['active_actions']._serialized_options = b'\030\001'
  _globals['_OPERATINGSTATUS']._serialized_start=4672
  _globals['_OPERATINGSTATUS']._serialized_end=4816
  _globals['_ZONE']._serialized_start=4818
  _globals['_ZONE']._serialized_end=4870
  _globals['_PUMPMODESTATE']._serialized_start=4873
  _globals['_PUMPMODESTATE']._serialized_end=5042
  _globals['_PUMPACTIVESTATE']._serialized_start=5045
  _globals['_PUMPACTIVESTATE']._serialized_end=5287
  _globals['_POWERPREFERENCE']._serialized_start=5289
  _globals['_POWERPREFERENCE']._serialized_end=5409
  _globals['_STATE']._serialized_start=811
  _globals['_STATE']._serialized_end=3432
  _globals['_HEATCURVES']._serialized_start=3435
  _globals['_HEATCURVES']._serialized_end=3601
  _globals['_COOLCURVES']._serialized_start=3604
  _globals['_COOLCURVES']._serialized_end=3770
  _globals['_DHWBOOST']._serialized_start=3772
  _globals['_DHWBOOST']._serialized_end=3880
  _globals['_ERRORMETADATA']._serialized_start=3883
  _globals['_ERRORMETADATA']._serialized_end=4035
  _globals['_THERMOSTAT']._serialized_start=4038
  _globals['_THERMOSTAT']._serialized_end=4311
  _globals['_ZONEPUMPMODESTATE']._serialized_start=4314
  _globals['_ZONEPUMPMODESTATE']._serialized_end=4449
  _globals['_SIGNATUREELEMENT']._serialized_start=4451
  _globals['_SIGNATUREELEMENT']._serialized_end=4503
  _globals['_HOTWATER']._serialized_start=4505
  _globals['_HOTWATER']._serialized_end=4565
  _globals['_SCHEDULER']._serialized_start=4567
  _globals['_SCHEDULER']._serialized_end=4669
# @@protoc_insertion_point(module_scope)