# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command_source.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/command_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0device/heat_pump/command/v1/command_source.proto\x12\x1b\x64\x65vice.heat_pump.command.v1*\xe0\x01\n\rCommandSource\x12\x1e\n\x1a\x43OMMAND_SOURCE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMMAND_SOURCE_APP_CONTROL\x10\x01\x12(\n$COMMAND_SOURCE_GOVERNMENT_REGULATION\x10\x05\x12 \n\x1c\x43OMMAND_SOURCE_SMART_CONTROL\x10\x02\x12\x1f\n\x1b\x43OMMAND_SOURCE_THINGS_BOARD\x10\x03\x12\"\n\x1e\x43OMMAND_SOURCE_WALL_THERMOSTAT\x10\x04\x42\xce\x01\n-com.aira.contract.device.heat_pump.command.v1B\x12\x43ommandSourceProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\022CommandSourceProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMANDSOURCE']._serialized_start=82
  _globals['_COMMANDSOURCE']._serialized_end=306
# @@protoc_insertion_point(module_scope)