# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/versions.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/versions.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/heat_pump/state/v1/versions.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"\xdc\x01\n\x10SoftwareVersions\x12\x16\n\x0elinux_build_id\x18\x01 \x01(\t\x12\x1c\n\x14\x63onnectivity_manager\x18\x02 \x01(\t\x12\x0f\n\x07\x63m_care\x18\x03 \x01(\t\x12\x17\n\x0fsilabs_firmware\x18\x04 \x01(\t\x12\x1d\n\x15\x63limate_control_villa\x18\x05 \x01(\t\x12 \n\x18outdoor_unit_application\x18\x08 \x01(\t\x12\x1b\n\x13outdoor_unit_eeprom\x18\t \x01(\tJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\x42\xbf\x01\n+com.aira.contract.device.heat_pump.state.v1B\rVersionsProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.versions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\rVersionsProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_SOFTWAREVERSIONS']._serialized_start=72
  _globals['_SOFTWAREVERSIONS']._serialized_end=292
# @@protoc_insertion_point(module_scope)