# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v1/notification_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v1/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import notification_pb2 as notification_dot_v1_dot_notification__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*notification/v1/notification_service.proto\x12\x0fnotification.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"notification/v1/notification.proto\x1a\x12util/v1/uuid.proto\"s\n\x17GetNotificationsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x10\x63reated_at_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x18\x01\"T\n\x18GetNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v1.Notification:\x02\x18\x01\"e\n\x17ReadNotificationRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12&\n\x0fnotification_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid:\x02\x18\x01\"\x1e\n\x18ReadNotificationResponse:\x02\x18\x01\"M\n\x18\x41\x64\x64\x46\x63mTokenToUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t:\x02\x18\x01\"\x1f\n\x19\x41\x64\x64\x46\x63mTokenToUserResponse:\x02\x18\x01\"R\n\x1dRemoveFcmTokenFromUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t:\x02\x18\x01\"$\n\x1eRemoveFcmTokenFromUserResponse:\x02\x18\x01\x32\xd3\x03\n\x13NotificationService\x12g\n\x10GetNotifications\x12(.notification.v1.GetNotificationsRequest\x1a).notification.v1.GetNotificationsResponse\x12g\n\x10ReadNotification\x12(.notification.v1.ReadNotificationRequest\x1a).notification.v1.ReadNotificationResponse\x12j\n\x11\x41\x64\x64\x46\x63mTokenToUser\x12).notification.v1.AddFcmTokenToUserRequest\x1a*.notification.v1.AddFcmTokenToUserResponse\x12y\n\x16RemoveFcmTokenFromUser\x12..notification.v1.RemoveFcmTokenFromUserRequest\x1a/.notification.v1.RemoveFcmTokenFromUserResponse\x1a\x03\x88\x02\x01\x42\x9a\x01\n!com.aira.contract.notification.v1B\x18NotificationServiceProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V1\xca\x02\x0fNotification\\V1\xe2\x02\x1bNotification\\V1\\GPBMetadata\xea\x02\x10Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v1.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v1B\030NotificationServiceProtoP\001\242\002\003NXX\252\002\017Notification.V1\312\002\017Notification\\V1\342\002\033Notification\\V1\\GPBMetadata\352\002\020Notification::V1'
  _globals['_GETNOTIFICATIONSREQUEST']._loaded_options = None
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_options = b'\030\001'
  _globals['_GETNOTIFICATIONSRESPONSE']._loaded_options = None
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_options = b'\030\001'
  _globals['_READNOTIFICATIONREQUEST']._loaded_options = None
  _globals['_READNOTIFICATIONREQUEST']._serialized_options = b'\030\001'
  _globals['_READNOTIFICATIONRESPONSE']._loaded_options = None
  _globals['_READNOTIFICATIONRESPONSE']._serialized_options = b'\030\001'
  _globals['_ADDFCMTOKENTOUSERREQUEST']._loaded_options = None
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_options = b'\030\001'
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._loaded_options = None
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_options = b'\030\001'
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._loaded_options = None
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_options = b'\030\001'
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._loaded_options = None
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_options = b'\030\001'
  _globals['_NOTIFICATIONSERVICE']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE']._serialized_options = b'\210\002\001'
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_start=152
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_end=267
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_start=269
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_end=353
  _globals['_READNOTIFICATIONREQUEST']._serialized_start=355
  _globals['_READNOTIFICATIONREQUEST']._serialized_end=456
  _globals['_READNOTIFICATIONRESPONSE']._serialized_start=458
  _globals['_READNOTIFICATIONRESPONSE']._serialized_end=488
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_start=490
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_end=567
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_start=569
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_end=600
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_start=602
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_end=684
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_start=686
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_end=722
  _globals['_NOTIFICATIONSERVICE']._serialized_start=725
  _globals['_NOTIFICATIONSERVICE']._serialized_end=1192
# @@protoc_insertion_point(module_scope)