# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/led_pattern.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/led_pattern.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+device/heat_pump/state/v1/led_pattern.proto\x12\x19\x64\x65vice.heat_pump.state.v1*\xdf\x02\n\nLedPattern\x12\x1b\n\x17LED_PATTERN_UNSPECIFIED\x10\x00\x12\x15\n\x11LED_PATTERN_BLACK\x10\t\x12\x16\n\x12LED_PATTERN_NORMAL\x10\x01\x12\x1d\n\x19LED_PATTERN_COMMISSIONING\x10\x02\x12\x1a\n\x16LED_PATTERN_PROCESSING\x10\x03\x12\x17\n\x13LED_PATTERN_COOLING\x10\x0b\x12\x19\n\x15LED_PATTERN_ATTENTION\x10\x04\x12\x19\n\x15LED_PATTERN_AWAY_MODE\x10\x05\x12$\n LED_PATTERN_ERROR_UNACKNOWLEDGED\x10\x06\x12\"\n\x1eLED_PATTERN_ERROR_ACKNOWLEDGED\x10\x07\x12\x17\n\x13LED_PATTERN_CONFIRM\x10\x08\x12\x18\n\x14LED_PATTERN_BOOSTING\x10\nB\xc1\x01\n+com.aira.contract.device.heat_pump.state.v1B\x0fLedPatternProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.led_pattern_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\017LedPatternProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_LEDPATTERN']._serialized_start=75
  _globals['_LEDPATTERN']._serialized_end=426
# @@protoc_insertion_point(module_scope)